\ Standard register and bit definitions 
\ for the Texas Instruments MSP430 microcontroller.

\ This file supports Forth development for MSP430G2553 devices.

\ derived from msp430g2553.h Texas Instruments, Version 1.0 Rev. 1.0, Setup

\ Vocabulary MSP430G2553
MSP430G2553 definitions


\ #if (((__TID__  >> 8 &  7F !=  2b     \   2b = 43 dec 
\ #error msp430g2553.h file for use with ICC430/A430 only
\ #endif 


\ STANDARD BITS

HEX

0001 CONSTANT BIT0  
0002 CONSTANT BIT1  
0004 CONSTANT BIT2  
0008 CONSTANT BIT3  
0010 CONSTANT BIT4  
0020 CONSTANT BIT5  
0040 CONSTANT BIT6  
0080 CONSTANT BIT7  
0100 CONSTANT BIT8  
0200 CONSTANT BIT9  
0400 CONSTANT BITA  
0800 CONSTANT BITB  
1000 CONSTANT BITC  
2000 CONSTANT BITD  
4000 CONSTANT BITE  
8000 CONSTANT BITF  

\ STATUS REGISTER BITS


0001 CONSTANT C     
0002 CONSTANT Z     
0004 CONSTANT N     
0100 CONSTANT V     
0008 CONSTANT GIE   
0010 CONSTANT CPUOFF
0020 CONSTANT OSCOFF
0040 CONSTANT SCG0  
0080 CONSTANT SCG1  

\  Low Power Modes coded with Bits 4-7 in SR 

\  Begin CONSTANTs for assembler 
CPUOFF CONSTANT LPM0     
SCG0 CPUOFF + CONSTANT LPM1     
SCG1 CPUOFF + CONSTANT LPM2     
SCG1 SCG0 + CPUOFF + CONSTANT LPM3     
SCG1 SCG0 + OSCOFF + CPUOFF + CONSTANT LPM4     
\  End CONSTANTs for assembler 

\  Begin CONSTANTs for C 
CPUOFF CONSTANT LPM0_bits
SCG0 CPUOFF + CONSTANT LPM1_bits
SCG1 CPUOFF + CONSTANT LPM2_bits
SCG1 SCG0 + CPUOFF + CONSTANT LPM3_bits
SCG1 SCG0 + OSCOFF + CPUOFF + CONSTANT LPM4_bits

\ #include "in430.h" \ IAR 

\  End CONSTANTs for C 

\ PERIPHERAL FILE MAP


\ SPECIAL FUNCTION REGISTER ADDRESSES  +  CONTROL BITS


0000  CONSTANT IE1        \  Interrupt Enable 1 
01    CONSTANT WDTIE      \  Watchdog Interrupt Enable 
02    CONSTANT OFIE       \  Osc. Fault  Interrupt Enable 
10    CONSTANT NMIIE      \  NMI Interrupt Enable 
20    CONSTANT ACCVIE     \  Flash Access Violation Interrupt Enable 

0002  CONSTANT IFG1       \  Interrupt Flag 1 
01    CONSTANT WDTIFG     \  Watchdog Interrupt Flag 
02    CONSTANT OFIFG      \  Osc. Fault Interrupt Flag 
04    CONSTANT PORIFG     \  Power On Interrupt Flag 
08    CONSTANT RSTIFG     \  Reset Interrupt Flag 
10    CONSTANT NMIIFG     \  NMI Interrupt Flag 

0001  CONSTANT IE2        \  Interrupt Enable 2 
IE2 CONSTANT UC0IE              
01 CONSTANT UCA0RXIE  
02 CONSTANT UCA0TXIE  
04 CONSTANT UCB0RXIE  
08 CONSTANT UCB0TXIE  

0003  CONSTANT IFG2       \  Interrupt Flag 2 
IFG2 CONSTANT UC0IFG             
01 CONSTANT UCA0RXIFG 
02 CONSTANT UCA0TXIFG 
04 CONSTANT UCB0RXIFG 
08 CONSTANT UCB0TXIFG 

\ ADC10

\ __MSP430_HAS_ADC10_             CONSTANT \  Definition to show that Module is available 

0048    CONSTANT ADC10DTC0   \  ADC10 Data Transfer Control 0 
0049    CONSTANT ADC10DTC1   \  ADC10 Data Transfer Control 1 
004A    CONSTANT ADC10AE0    \  ADC10 Analog Enable 0 

01B0    CONSTANT ADC10CTL0   \  ADC10 Control 0 
01B2    CONSTANT ADC10CTL1   \  ADC10 Control 1 
01B4    CONSTANT ADC10MEM    \  ADC10 Memory 
01BC    CONSTANT ADC10SA     \  ADC10 Data Transfer Start Address 

\  ADC10CTL0 
001     CONSTANT ADC10SC     \  ADC10 Start Conversion 
002     CONSTANT ENC         \  ADC10 Enable Conversion 
004     CONSTANT ADC10IFG    \  ADC10 Interrupt Flag 
008     CONSTANT ADC10IE     \  ADC10 Interrupt Enalbe 
010     CONSTANT ADC10ON     \  ADC10 On/Enable 
020     CONSTANT REFON       \  ADC10 Reference on 
040     CONSTANT REF2_5V     \  ADC10 Ref 0:1.5V / 1:2.5V 
080     CONSTANT MSC         \  ADC10 Multiple SampleConversion 
100     CONSTANT REFBURST    \  ADC10 Reference Burst Mode 
200     CONSTANT REFOUT      \  ADC10 Enalbe output of Ref. 
400     CONSTANT ADC10SR     \  ADC10 Sampling Rate 0:200ksps / 1:50ksps 
800     CONSTANT ADC10SHT0   \  ADC10 Sample Hold Select Bit: 0 
1000    CONSTANT ADC10SHT1   \  ADC10 Sample Hold Select Bit: 1 
2000    CONSTANT SREF0       \  ADC10 Reference Select Bit: 0 
4000    CONSTANT SREF1       \  ADC10 Reference Select Bit: 1 
8000    CONSTANT SREF2       \  ADC10 Reference Select Bit: 2 
0 800   * CONSTANT ADC10SHT_0 \  4 x ADC10CLKs 
1 800   * CONSTANT ADC10SHT_1 \  8 x ADC10CLKs 
2 800   * CONSTANT ADC10SHT_2 \  16 x ADC10CLKs 
3 800   * CONSTANT ADC10SHT_3 \  64 x ADC10CLKs 

0 2000  * CONSTANT SREF_0     \  VR +  = AVCC and VR- = AVSS 
1 2000  * CONSTANT SREF_1     \  VR +  = VREF +  and VR- = AVSS 
2 2000  * CONSTANT SREF_2     \  VR +  = VEREF +  and VR- = AVSS 
3 2000  * CONSTANT SREF_3     \  VR +  = VEREF +  and VR- = AVSS 
4 2000  * CONSTANT SREF_4     \  VR +  = AVCC and VR- = VREF-/VEREF- 
5 2000  * CONSTANT SREF_5     \  VR +  = VREF +  and VR- = VREF-/VEREF- 
6 2000  * CONSTANT SREF_6     \  VR +  = VEREF +  and VR- = VREF-/VEREF- 
7 2000  * CONSTANT SREF_7     \  VR +  = VEREF +  and VR- = VREF-/VEREF- 

\  ADC10CTL1 
0001    CONSTANT ADC10BUSY   \  ADC10 BUSY 
0002    CONSTANT CONSEQ0     \  ADC10 Conversion Sequence Select 0 
0004    CONSTANT CONSEQ1     \  ADC10 Conversion Sequence Select 1 
0008    CONSTANT ADC10SSEL0  \  ADC10 Clock Source Select Bit: 0 
0010    CONSTANT ADC10SSEL1  \  ADC10 Clock Source Select Bit: 1 
0020    CONSTANT ADC10DIV0   \  ADC10 Clock Divider Select Bit: 0 
0040    CONSTANT ADC10DIV1   \  ADC10 Clock Divider Select Bit: 1 
0080    CONSTANT ADC10DIV2   \  ADC10 Clock Divider Select Bit: 2 
0100    CONSTANT ISSH        \  ADC10 Invert Sample Hold Signal 
0200    CONSTANT ADC10DF     \  ADC10 Data Format 0:binary 1:2's complement 
0400    CONSTANT SHS0        \  ADC10 Sample/Hold Source Bit: 0 
0800    CONSTANT SHS1        \  ADC10 Sample/Hold Source Bit: 1 
1000    CONSTANT INCH0       \  ADC10 Input Channel Select Bit: 0 
2000    CONSTANT INCH1       \  ADC10 Input Channel Select Bit: 1 
4000    CONSTANT INCH2       \  ADC10 Input Channel Select Bit: 2 
8000    CONSTANT INCH3       \  ADC10 Input Channel Select Bit: 3 

0 2       * CONSTANT CONSEQ_0   \  Single channel single conversion 
1 2       * CONSTANT CONSEQ_1   \  Sequence of channels 
2 2       * CONSTANT CONSEQ_2   \  Repeat single channel 
3 2       * CONSTANT CONSEQ_3   \  Repeat sequence of channels 

0 8       * CONSTANT ADC10SSEL_0          \  ADC10OSC 
1 8       * CONSTANT ADC10SSEL_1          \  ACLK 
2 8       * CONSTANT ADC10SSEL_2          \  MCLK 
3 8       * CONSTANT ADC10SSEL_3          \  SMCLK 

0 20    * CONSTANT ADC10DIV_0 \  ADC10 Clock Divider Select 0 
1 20    * CONSTANT ADC10DIV_1 \  ADC10 Clock Divider Select 1 
2 20    * CONSTANT ADC10DIV_2 \  ADC10 Clock Divider Select 2 
3 20    * CONSTANT ADC10DIV_3 \  ADC10 Clock Divider Select 3 
4 20    * CONSTANT ADC10DIV_4 \  ADC10 Clock Divider Select 4 
5 20    * CONSTANT ADC10DIV_5 \  ADC10 Clock Divider Select 5 
6 20    * CONSTANT ADC10DIV_6 \  ADC10 Clock Divider Select 6 
7 20    * CONSTANT ADC10DIV_7 \  ADC10 Clock Divider Select 7 

0 400   * CONSTANT SHS_0      \  ADC10SC 
1 400   * CONSTANT SHS_1      \  TA3 OUT1 
2 400   * CONSTANT SHS_2      \  TA3 OUT0 
3 400   * CONSTANT SHS_3      \  TA3 OUT2 

0 1000  * CONSTANT INCH_0     \  Selects Channel 0 
1 1000  * CONSTANT INCH_1     \  Selects Channel 1 
2 1000  * CONSTANT INCH_2     \  Selects Channel 2 
3 1000  * CONSTANT INCH_3     \  Selects Channel 3 
4 1000  * CONSTANT INCH_4     \  Selects Channel 4 
5 1000  * CONSTANT INCH_5     \  Selects Channel 5 
6 1000  * CONSTANT INCH_6     \  Selects Channel 6 
7 1000  * CONSTANT INCH_7     \  Selects Channel 7 
8 1000  * CONSTANT INCH_8     \  Selects Channel 8 
9 1000  * CONSTANT INCH_9     \  Selects Channel 9 
A 1000  * CONSTANT INCH_10    \  Selects Channel 10 
B 1000  * CONSTANT INCH_11    \  Selects Channel 11 
C 1000  * CONSTANT INCH_12    \  Selects Channel 12 
D 1000  * CONSTANT INCH_13    \  Selects Channel 13 
E 1000  * CONSTANT INCH_14    \  Selects Channel 14 
F 1000  * CONSTANT INCH_15    \  Selects Channel 15 

\  ADC10DTC0 
001     CONSTANT ADC10FETCH  \  This bit should normally be reset 
002     CONSTANT ADC10B1     \  ADC10 block one 
004     CONSTANT ADC10CT     \  ADC10 continuous transfer 
008     CONSTANT ADC10TB     \  ADC10 two-block mode 
000     CONSTANT ADC10DISABLE          \  ADC10DTC1 

\ Basic Clock Module

\ __MSP430_HAS_BC2_             CONSTANT \  Definition to show that Module is available 

0056  CONSTANT DCOCTL      \  DCO Clock Frequency Control 
0057  CONSTANT BCSCTL1     \  Basic Clock System Control 1 
0058  CONSTANT BCSCTL2     \  Basic Clock System Control 2 
0053  CONSTANT BCSCTL3     \  Basic Clock System Control 3 

01   CONSTANT MOD0        \  Modulation Bit 0 
02   CONSTANT MOD1        \  Modulation Bit 1 
04   CONSTANT MOD2        \  Modulation Bit 2 
08   CONSTANT MOD3        \  Modulation Bit 3 
10   CONSTANT MOD4        \  Modulation Bit 4 
20   CONSTANT DCO0        \  DCO Select Bit 0 
40   CONSTANT DCO1        \  DCO Select Bit 1 
80   CONSTANT DCO2        \  DCO Select Bit 2 

01   CONSTANT RSEL0       \  Range Select Bit 0 
02   CONSTANT RSEL1       \  Range Select Bit 1 
04   CONSTANT RSEL2       \  Range Select Bit 2 
08   CONSTANT RSEL3       \  Range Select Bit 3 
10   CONSTANT DIVA0       \  ACLK Divider 0 
20   CONSTANT DIVA1       \  ACLK Divider 1 
40   CONSTANT XTS         \  LFXTCLK 0:Low Freq. / 1: High Freq. 
80   CONSTANT XT2OFF      \  Enable XT2CLK 

00   CONSTANT DIVA_0      \  ACLK Divider 0: /1 
10   CONSTANT DIVA_1      \  ACLK Divider 1: /2 
20   CONSTANT DIVA_2      \  ACLK Divider 2: /4 
30   CONSTANT DIVA_3      \  ACLK Divider 3: /8 

02   CONSTANT DIVS0       \  SMCLK Divider 0 
04   CONSTANT DIVS1       \  SMCLK Divider 1 
08   CONSTANT SELS        \  SMCLK Source Select 0:DCOCLK / 1:XT2CLK/LFXTCLK 
10   CONSTANT DIVM0       \  MCLK Divider 0 
20   CONSTANT DIVM1       \  MCLK Divider 1 
40   CONSTANT SELM0       \  MCLK Source Select 0 
80   CONSTANT SELM1       \  MCLK Source Select 1 

00   CONSTANT DIVS_0      \  SMCLK Divider 0: /1 
02   CONSTANT DIVS_1      \  SMCLK Divider 1: /2 
04   CONSTANT DIVS_2      \  SMCLK Divider 2: /4 
06   CONSTANT DIVS_3      \  SMCLK Divider 3: /8 

00   CONSTANT DIVM_0      \  MCLK Divider 0: /1 
10   CONSTANT DIVM_1      \  MCLK Divider 1: /2 
20   CONSTANT DIVM_2      \  MCLK Divider 2: /4 
30   CONSTANT DIVM_3      \  MCLK Divider 3: /8 

00   CONSTANT SELM_0      \  MCLK Source Select 0: DCOCLK 
40   CONSTANT SELM_1      \  MCLK Source Select 1: DCOCLK 
80   CONSTANT SELM_2      \  MCLK Source Select 2: XT2CLK/LFXTCLK 
C0   CONSTANT SELM_3      \  MCLK Source Select 3: LFXTCLK 

01   CONSTANT LFXT1OF     \  Low/high Frequency Oscillator Fault Flag 
02   CONSTANT XT2OF       \  High frequency oscillator 2 fault flag 
04   CONSTANT XCAP0       \  XIN/XOUT Cap 0 
08   CONSTANT XCAP1       \  XIN/XOUT Cap 1 
10   CONSTANT LFXT1S0     \  Mode 0 for LFXT1  XTS = 0 
20   CONSTANT LFXT1S1     \  Mode 1 for LFXT1  XTS = 0 
40   CONSTANT XT2S0       \  Mode 0 for XT2 
80   CONSTANT XT2S1       \  Mode 1 for XT2 

00   CONSTANT XCAP_0      \  XIN/XOUT Cap : 0 pF 
04   CONSTANT XCAP_1      \  XIN/XOUT Cap : 6 pF 
08   CONSTANT XCAP_2      \  XIN/XOUT Cap : 10 pF 
0C   CONSTANT XCAP_3      \  XIN/XOUT Cap : 12.5 pF 

00   CONSTANT LFXT1S_0    \  Mode 0 for LFXT1 : Normal operation 
10   CONSTANT LFXT1S_1    \  Mode 1 for LFXT1 : Reserved 
20   CONSTANT LFXT1S_2    \  Mode 2 for LFXT1 : VLO 
30   CONSTANT LFXT1S_3    \  Mode 3 for LFXT1 : Digital input signal 

00   CONSTANT XT2S_0      \  Mode 0 for XT2 : 0.4 - 1 MHz 
40   CONSTANT XT2S_1      \  Mode 1 for XT2 : 1 - 4 MHz 
80   CONSTANT XT2S_2      \  Mode 2 for XT2 : 2 - 16 MHz 
C0   CONSTANT XT2S_3      \  Mode 3 for XT2 : Digital input signal 

\ Comparator A

\ __MSP430_HAS_CAPLUS_          CONSTANT \  Definition to show that Module is available 

0059  CONSTANT CACTL1      \  Comparator A Control 1 
005A  CONSTANT CACTL2      \  Comparator A Control 2 
005B  CONSTANT CAPD        \  Comparator A Port Disable 

01    CONSTANT CAIFG       \  Comp. A Interrupt Flag 
02    CONSTANT CAIE        \  Comp. A Interrupt Enable 
04    CONSTANT CAIES       \  Comp. A Int. Edge Select: 0:rising / 1:falling 
08    CONSTANT CAON        \  Comp. A enable 
10    CONSTANT CAREF0      \  Comp. A Internal Reference Select 0 
20    CONSTANT CAREF1      \  Comp. A Internal Reference Select 1 
40    CONSTANT CARSEL      \  Comp. A Internal Reference Enable 
80    CONSTANT CAEX        \  Comp. A Exchange Inputs 

00    CONSTANT CAREF_0     \  Comp. A Int. Ref. Select 0 : Off 
10    CONSTANT CAREF_1     \  Comp. A Int. Ref. Select 1 : 0.25 * Vcc 
20    CONSTANT CAREF_2     \  Comp. A Int. Ref. Select 2 : 0.5 * Vcc 
30    CONSTANT CAREF_3     \  Comp. A Int. Ref. Select 3 : Vt

01    CONSTANT CAOUT       \  Comp. A Output 
02    CONSTANT CAF         \  Comp. A Enable Output Filter 
04    CONSTANT P2CA0       \  Comp. A  + Terminal Multiplexer 
08    CONSTANT P2CA1       \  Comp. A -Terminal Multiplexer 
10    CONSTANT P2CA2       \  Comp. A -Terminal Multiplexer 
20    CONSTANT P2CA3       \  Comp. A -Terminal Multiplexer 
40    CONSTANT P2CA4       \  Comp. A  + Terminal Multiplexer 
80    CONSTANT CASHORT     \  Comp. A Short  +  and - Terminals 

01    CONSTANT CAPD0       \  Comp. A Disable Input Buffer of Port Register .0 
02    CONSTANT CAPD1       \  Comp. A Disable Input Buffer of Port Register .1 
04    CONSTANT CAPD2       \  Comp. A Disable Input Buffer of Port Register .2 
08    CONSTANT CAPD3       \  Comp. A Disable Input Buffer of Port Register .3 
10    CONSTANT CAPD4       \  Comp. A Disable Input Buffer of Port Register .4 
20    CONSTANT CAPD5       \  Comp. A Disable Input Buffer of Port Register .5 
40    CONSTANT CAPD6       \  Comp. A Disable Input Buffer of Port Register .6 
80    CONSTANT CAPD7       \  Comp. A Disable Input Buffer of Port Register .7 

\ Flash Memory

\ __MSP430_HAS_FLASH2_          CONSTANT \  Definition to show that Module is available 

0128  CONSTANT FCTL1       \  FLASH Control 1 
012A  CONSTANT FCTL2       \  FLASH Control 2 
012C  CONSTANT FCTL3       \  FLASH Control 3 

9600  CONSTANT FRKEY       \  Flash key returned by read 
A500  CONSTANT FWKEY       \  Flash key for write 
3300  CONSTANT FXKEY       \  for use with XOR instruction 

0002  CONSTANT ERASE       \  Enable bit for Flash segment erase 
0004  CONSTANT MERAS       \  Enable bit for Flash mass erase 
0040  CONSTANT WRT         \  Enable bit for Flash write 
0080  CONSTANT BLKWRT      \  Enable bit for Flash segment write 
0080  CONSTANT SEGWRT      \  old definition  \  Enable bit for Flash segment write 

0001  CONSTANT FN0         \  Divide Flash clock by 1 to 64 using FN0 to FN5 according to: 
0002  CONSTANT FN1         \   32 * FN5  +  16 * FN4  +  8 * FN3  +  4 * FN2  +  2 * FN1  +  FN0  +  1 
\ #ifndef FN2
0004 CONSTANT FN2        
\ #endif
\ #ifndef FN3
0008 CONSTANT FN3        
\ #endif
\ #ifndef FN4
0010 CONSTANT FN4        
\ #endif
0020 CONSTANT FN5        
0040  CONSTANT FSSEL0      \  Flash clock select 0         \  to distinguish from USART SSELx 
0080  CONSTANT FSSEL1      \  Flash clock select 1 

0000  CONSTANT FSSEL_0     \  Flash clock select: 0 - ACLK 
0040  CONSTANT FSSEL_1     \  Flash clock select: 1 - MCLK 
0080  CONSTANT FSSEL_2     \  Flash clock select: 2 - SMCLK 
00C0  CONSTANT FSSEL_3     \  Flash clock select: 3 - SMCLK 

0001  CONSTANT BUSY        \  Flash busy: 1 
0002  CONSTANT KEYV        \  Flash Key violation flag 
0004  CONSTANT ACCVIFG     \  Flash Access violation flag 
0008  CONSTANT WAIT        \  Wait flag for segment write 
0010  CONSTANT LOCK        \  Lock bit: 1 - Flash is locked (read only) 
0020  CONSTANT EMEX        \  Flash Emergency Exit 
0040  CONSTANT LOCKA       \  Segment A Lock bit: read = 1 - Segment is locked (read only) 
0080  CONSTANT FAIL        \  Last Program or Erase failed 

\ DIGITAL I/O Port1/2 Pull up / Pull down Resistors

\ __MSP430_HAS_PORT1_R_         CONSTANT \  Definition to show that Module is available 
\ __MSP430_HAS_PORT2_R_         CONSTANT \  Definition to show that Module is available 

0020  CONSTANT P1IN        \  Port 1 Input 
0021  CONSTANT P1OUT       \  Port 1 Output 
0022  CONSTANT P1DIR       \  Port 1 Direction 
0023  CONSTANT P1IFG       \  Port 1 Interrupt Flag 
0024  CONSTANT P1IES       \  Port 1 Interrupt Edge Select 
0025  CONSTANT P1IE        \  Port 1 Interrupt Enable 
0026  CONSTANT P1SEL       \  Port 1 Selection 
0041  CONSTANT P1SEL2      \  Port 1 Selection 2 
0027  CONSTANT P1REN       \  Port 1 Resistor Enable 

0028  CONSTANT P2IN        \  Port 2 Input 
0029  CONSTANT P2OUT       \  Port 2 Output 
002A  CONSTANT P2DIR       \  Port 2 Direction 
002B  CONSTANT P2IFG       \  Port 2 Interrupt Flag 
002C  CONSTANT P2IES       \  Port 2 Interrupt Edge Select 
002D  CONSTANT P2IE        \  Port 2 Interrupt Enable 
002E  CONSTANT P2SEL       \  Port 2 Selection 
0042  CONSTANT P2SEL2      \  Port 2 Selection 2 
002F  CONSTANT P2REN       \  Port 2 Resistor Enable 

\ DIGITAL I/O Port3 Pull up / Pull down Resistors

\ __MSP430_HAS_PORT3_R_           CONSTANT \  Definition to show that Module is available 

0018  CONSTANT P3IN        \  Port 3 Input 
0019  CONSTANT P3OUT       \  Port 3 Output 
001A  CONSTANT P3DIR       \  Port 3 Direction 
001B  CONSTANT P3SEL       \  Port 3 Selection 
0043  CONSTANT P3SEL2      \  Port 3 Selection 2 
0010  CONSTANT P3REN       \  Port 3 Resistor Enable 

\ Timer0_A3

\ __MSP430_HAS_TA3_             CONSTANT \  Definition to show that Module is available 

012E  CONSTANT TA0IV       \  Timer0_A3 Interrupt Vector Word 
0160  CONSTANT TA0CTL      \  Timer0_A3 Control 
0162  CONSTANT TA0CCTL0    \  Timer0_A3 Capture/Compare Control 0 
0164  CONSTANT TA0CCTL1    \  Timer0_A3 Capture/Compare Control 1 
0166  CONSTANT TA0CCTL2    \  Timer0_A3 Capture/Compare Control 2 
0170  CONSTANT TA0R        \  Timer0_A3 
0172  CONSTANT TA0CCR0     \  Timer0_A3 Capture/Compare 0 
0174  CONSTANT TA0CCR1     \  Timer0_A3 Capture/Compare 1 
0176  CONSTANT TA0CCR2     \  Timer0_A3 Capture/Compare 2 

\  Alternate register names 
TA0IV     CONSTANT TAIV                \  Timer A Interrupt Vector Word 
TA0CTL    CONSTANT TACTL               \  Timer A Control 
TA0CCTL0  CONSTANT TACCTL0             \  Timer A Capture/Compare Control 0 
TA0CCTL1  CONSTANT TACCTL1             \  Timer A Capture/Compare Control 1 
TA0CCTL2  CONSTANT TACCTL2             \  Timer A Capture/Compare Control 2 
TA0R      CONSTANT TAR                 \  Timer A 
TA0CCR0   CONSTANT TACCR0              \  Timer A Capture/Compare 0 
TA0CCR1   CONSTANT TACCR1              \  Timer A Capture/Compare 1 
TA0CCR2   CONSTANT TACCR2              \  Timer A Capture/Compare 2 
TA0IV     CONSTANT TAIV                \  Timer A Interrupt Vector Word 
TA0CTL    CONSTANT TACTL               \  Timer A Control 
TA0CCTL0  CONSTANT TACCTL0             \  Timer A Capture/Compare Control 0 
TA0CCTL1  CONSTANT TACCTL1             \  Timer A Capture/Compare Control 1 
TA0CCTL2  CONSTANT TACCTL2             \  Timer A Capture/Compare Control 2 
TA0R      CONSTANT TAR                 \  Timer A 
TA0CCR0   CONSTANT TACCR0              \  Timer A Capture/Compare 0 
TA0CCR1   CONSTANT TACCR1              \  Timer A Capture/Compare 1 
TA0CCR2   CONSTANT TACCR2              \  Timer A Capture/Compare 2 

\  Alternate register names 2 
TACCTL0   CONSTANT CCTL0               \  Timer A Capture/Compare Control 0 
TACCTL1   CONSTANT CCTL1               \  Timer A Capture/Compare Control 1 
TACCTL2   CONSTANT CCTL2               \  Timer A Capture/Compare Control 2 
TACCR0    CONSTANT CCR0                \  Timer A Capture/Compare 0 
TACCR1    CONSTANT CCR1                \  Timer A Capture/Compare 1 
TACCR2    CONSTANT CCR2                \  Timer A Capture/Compare 2 
TACCTL0   CONSTANT CCTL0               \  Timer A Capture/Compare Control 0 
TACCTL1   CONSTANT CCTL1               \  Timer A Capture/Compare Control 1 
TACCTL2   CONSTANT CCTL2               \  Timer A Capture/Compare Control 2 
TACCR0    CONSTANT CCR0                \  Timer A Capture/Compare 0 
TACCR1    CONSTANT CCR1                \  Timer A Capture/Compare 1 
TACCR2    CONSTANT CCR2                \  Timer A Capture/Compare 2 

0200  CONSTANT TASSEL1     \  Timer A clock source select 0 
0100  CONSTANT TASSEL0     \  Timer A clock source select 1 
0080  CONSTANT ID1         \  Timer A clock input divider 1 
0040  CONSTANT ID0         \  Timer A clock input divider 0 
0020  CONSTANT MC1         \  Timer A mode control 1 
0010  CONSTANT MC0         \  Timer A mode control 0 
0004  CONSTANT TACLR       \  Timer A counter clear 
0002  CONSTANT TAIE        \  Timer A counter interrupt enable 
0001  CONSTANT TAIFG       \  Timer A counter interrupt flag 

0 10  * CONSTANT MC_0       \  Timer A mode control: 0 - Stop 
1 10  * CONSTANT MC_1       \  Timer A mode control: 1 - Up to CCR0 
2 10  * CONSTANT MC_2       \  Timer A mode control: 2 - Continous up 
3 10  * CONSTANT MC_3       \  Timer A mode control: 3 - Up/Down 
0 40  * CONSTANT ID_0       \  Timer A input divider: 0 - /1 
1 40  * CONSTANT ID_1       \  Timer A input divider: 1 - /2 
2 40  * CONSTANT ID_2       \  Timer A input divider: 2 - /4 
3 40  * CONSTANT ID_3       \  Timer A input divider: 3 - /8 
0 100 * CONSTANT TASSEL_0   \  Timer A clock source select: 0 - TACLK 
1 100 * CONSTANT TASSEL_1   \  Timer A clock source select: 1 - ACLK  
2 100 * CONSTANT TASSEL_2   \  Timer A clock source select: 2 - SMCLK 
3 100 * CONSTANT TASSEL_3   \  Timer A clock source select: 3 - INCLK 

8000  CONSTANT CM1         \  Capture mode 1 
4000  CONSTANT CM0         \  Capture mode 0 
2000  CONSTANT CCIS1       \  Capture input select 1 
1000  CONSTANT CCIS0       \  Capture input select 0 
0800  CONSTANT SCS         \  Capture sychronize 
0400  CONSTANT SCCI        \  Latched capture signal (read) 
0100  CONSTANT CAP         \  Capture mode: 1 /Compare mode : 0 
0080  CONSTANT OUTMOD2     \  Output mode 2 
0040  CONSTANT OUTMOD1     \  Output mode 1 
0020  CONSTANT OUTMOD0     \  Output mode 0 
0010  CONSTANT CCIE        \  Capture/compare interrupt enable 
0008  CONSTANT CCI         \  Capture input signal (read) 
0004  CONSTANT OUT         \  PWM Output signal if output mode 0 
0002  CONSTANT COV         \  Capture/compare overflow flag 
0001  CONSTANT CCIFG       \  Capture/compare interrupt flag 

0 20  * CONSTANT OUTMOD_0   \  PWM output mode: 0 - output only 
1 20  * CONSTANT OUTMOD_1   \  PWM output mode: 1 - set 
2 20  * CONSTANT OUTMOD_2   \  PWM output mode: 2 - PWM toggle/reset 
3 20  * CONSTANT OUTMOD_3   \  PWM output mode: 3 - PWM set/reset 
4 20  * CONSTANT OUTMOD_4   \  PWM output mode: 4 - toggle 
5 20  * CONSTANT OUTMOD_5   \  PWM output mode: 5 - Reset 
6 20  * CONSTANT OUTMOD_6   \  PWM output mode: 6 - PWM toggle/set 
7 20  * CONSTANT OUTMOD_7   \  PWM output mode: 7 - PWM reset/set 
0 1000 * CONSTANT CCIS_0     \  Capture input select: 0 - CCIxA 
1 1000 * CONSTANT CCIS_1     \  Capture input select: 1 - CCIxB 
2 1000 * CONSTANT CCIS_2     \  Capture input select: 2 - GND 
3 1000 * CONSTANT CCIS_3     \  Capture input select: 3 - Vcc 
0 4000 * CONSTANT CM_0       \  Capture mode: 0 - disabled 
1 4000 * CONSTANT CM_1       \  Capture mode: 1 - pos. edge 
2 4000 * CONSTANT CM_2       \  Capture mode: 1 - neg. edge 
3 4000 * CONSTANT CM_3       \  Capture mode: 1 - both edges 

\  T0_A3IV Definitions 
0000    CONSTANT TA0IV_NONE  \  No Interrupt pending 
0002    CONSTANT TA0IV_TACCR1          \  TA0CCR1_CCIFG 
0004    CONSTANT TA0IV_TACCR2          \  TA0CCR2_CCIFG 
0006    CONSTANT TA0IV_6     \  Reserved 
0008    CONSTANT TA0IV_8     \  Reserved 
000A    CONSTANT TA0IV_TAIFG           \  TA0IFG 

\ Timer1_A3

\ __MSP430_HAS_T1A3_            CONSTANT \  Definition to show that Module is available 

011E  CONSTANT TA1IV       \  Timer1_A3 Interrupt Vector Word 
0180  CONSTANT TA1CTL      \  Timer1_A3 Control 
0182  CONSTANT TA1CCTL0    \  Timer1_A3 Capture/Compare Control 0 
0184  CONSTANT TA1CCTL1    \  Timer1_A3 Capture/Compare Control 1 
0186  CONSTANT TA1CCTL2    \  Timer1_A3 Capture/Compare Control 2 
0190  CONSTANT TA1R        \  Timer1_A3 
0192  CONSTANT TA1CCR0     \  Timer1_A3 Capture/Compare 0 
0194  CONSTANT TA1CCR1     \  Timer1_A3 Capture/Compare 1 
0196  CONSTANT TA1CCR2     \  Timer1_A3 Capture/Compare 2 

\  Bits are already defined within the Timer0_Ax 

\  T1_A3IV Definitions 
0000    CONSTANT TA1IV_NONE  \  No Interrupt pending 
0002    CONSTANT TA1IV_TACCR1          \  TA1CCR1_CCIFG 
0004    CONSTANT TA1IV_TACCR2          \  TA1CCR2_CCIFG 
000A    CONSTANT TA1IV_TAIFG           \  TA1IFG 

\ USCI

\ __MSP430_HAS_USCI_            CONSTANT \  Definition to show that Module is available 

0060  CONSTANT UCA0CTL0    \  USCI A0 Control Register 0 
0061  CONSTANT UCA0CTL1    \  USCI A0 Control Register 1 
0062  CONSTANT UCA0BR0     \  USCI A0 Baud Rate 0 
0063  CONSTANT UCA0BR1     \  USCI A0 Baud Rate 1 
0064  CONSTANT UCA0MCTL    \  USCI A0 Modulation Control 
0065  CONSTANT UCA0STAT    \  USCI A0 Status Register 
0066  CONSTANT UCA0RXBUF   \  USCI A0 Receive Buffer 
0067  CONSTANT UCA0TXBUF   \  USCI A0 Transmit Buffer 
005D  CONSTANT UCA0ABCTL   \  USCI A0 LIN Control 
005E  CONSTANT UCA0IRTCTL            \  USCI A0 IrDA Transmit Control 
005F  CONSTANT UCA0IRRCTL            \  USCI A0 IrDA Receive Control 



0068  CONSTANT UCB0CTL0    \  USCI B0 Control Register 0 
0069  CONSTANT UCB0CTL1    \  USCI B0 Control Register 1 
006A  CONSTANT UCB0BR0     \  USCI B0 Baud Rate 0 
006B  CONSTANT UCB0BR1     \  USCI B0 Baud Rate 1 
006C  CONSTANT UCB0I2CIE   \  USCI B0 I2C Interrupt Enable Register 
006D  CONSTANT UCB0STAT    \  USCI B0 Status Register 
006E  CONSTANT UCB0RXBUF   \  USCI B0 Receive Buffer 
006F  CONSTANT UCB0TXBUF   \  USCI B0 Transmit Buffer 
0118  CONSTANT UCB0I2COA   \  USCI B0 I2C Own Address 
011A  CONSTANT UCB0I2CSA   \  USCI B0 I2C Slave Address 

\  UART-Mode Bits
80    CONSTANT UCPEN       \  Async. Mode: Parity enable 
40    CONSTANT UCPAR       \  Async. Mode: Parity     0:odd / 1:even 
20    CONSTANT UCMSB       \  Async. Mode: MSB first  0:LSB / 1:MSB 
10    CONSTANT UC7BIT      \  Async. Mode: Data Bits  0:8-bits / 1:7-bits 
08    CONSTANT UCSPB       \  Async. Mode: Stop Bits  0:one / 1: two 
04    CONSTANT UCMODE1     \  Async. Mode: USCI Mode 1 
02    CONSTANT UCMODE0     \  Async. Mode: USCI Mode 0 
01    CONSTANT UCSYNC      \  Sync-Mode  0:UART-Mode / 1:SPI-Mode 

\  SPI-Mode Bits
80    CONSTANT UCCKPH      \  Sync. Mode: Clock Phase 
40    CONSTANT UCCKPL      \  Sync. Mode: Clock Polarity 
08    CONSTANT UCMST       \  Sync. Mode: Master Select 

\  I2C-Mode Bits
80    CONSTANT UCA10       \  10-bit Address Mode 
40    CONSTANT UCSLA10     \  10-bit Slave Address Mode 
20    CONSTANT UCMM        \  Multi-Master Environment 
\ CONSTANT res       10    \  reserved 
00    CONSTANT UCMODE_0    \  Sync. Mode: USCI Mode: 0 
02    CONSTANT UCMODE_1    \  Sync. Mode: USCI Mode: 1 
04    CONSTANT UCMODE_2    \  Sync. Mode: USCI Mode: 2 
06    CONSTANT UCMODE_3    \  Sync. Mode: USCI Mode: 3 

\  UART-Mode Bits
80    CONSTANT UCSSEL1     \  USCI 0 Clock Source Select 1 
40    CONSTANT UCSSEL0     \  USCI 0 Clock Source Select 0 
20    CONSTANT UCRXEIE     \  RX Error interrupt enable 
10    CONSTANT UCBRKIE     \  Break interrupt enable 
08    CONSTANT UCDORM      \  Dormant (Sleep Mode) 
04    CONSTANT UCTXADDR    \  Send next Data as Address 
02    CONSTANT UCTXBRK     \  Send next Data as Break 
01    CONSTANT UCSWRST     \  USCI Software Reset 

\  SPI-Mode Bits
\ CONSTANT res       20    \  reserved 
\ CONSTANT res       10    \  reserved 
\ CONSTANT res       08    \  reserved 
\ CONSTANT res       04    \  reserved 
\ CONSTANT res       02    \  reserved 

\  I2C-Mode Bits
\ CONSTANT res       20    \  reserved 
10    CONSTANT UCTR        \  Transmit/Receive Select/Flag 
08    CONSTANT UCTXNACK    \  Transmit NACK 
04    CONSTANT UCTXSTP     \  Transmit STOP 
02    CONSTANT UCTXSTT     \  Transmit START 
00    CONSTANT UCSSEL_0    \  USCI 0 Clock Source: 0 
40    CONSTANT UCSSEL_1    \  USCI 0 Clock Source: 1 
80    CONSTANT UCSSEL_2    \  USCI 0 Clock Source: 2 
C0    CONSTANT UCSSEL_3    \  USCI 0 Clock Source: 3 

80    CONSTANT UCBRF3      \  USCI First Stage Modulation Select 3 
40    CONSTANT UCBRF2      \  USCI First Stage Modulation Select 2 
20    CONSTANT UCBRF1      \  USCI First Stage Modulation Select 1 
10    CONSTANT UCBRF0      \  USCI First Stage Modulation Select 0 
08    CONSTANT UCBRS2      \  USCI Second Stage Modulation Select 2 
04    CONSTANT UCBRS1      \  USCI Second Stage Modulation Select 1 
02    CONSTANT UCBRS0      \  USCI Second Stage Modulation Select 0 
01    CONSTANT UCOS16      \  USCI 16-times Oversampling enable 

00    CONSTANT UCBRF_0     \  USCI First Stage Modulation: 0 
10    CONSTANT UCBRF_1     \  USCI First Stage Modulation: 1 
20    CONSTANT UCBRF_2     \  USCI First Stage Modulation: 2 
30    CONSTANT UCBRF_3     \  USCI First Stage Modulation: 3 
40    CONSTANT UCBRF_4     \  USCI First Stage Modulation: 4 
50    CONSTANT UCBRF_5     \  USCI First Stage Modulation: 5 
60    CONSTANT UCBRF_6     \  USCI First Stage Modulation: 6 
70    CONSTANT UCBRF_7     \  USCI First Stage Modulation: 7 
80    CONSTANT UCBRF_8     \  USCI First Stage Modulation: 8 
90    CONSTANT UCBRF_9     \  USCI First Stage Modulation: 9 
A0    CONSTANT UCBRF_10    \  USCI First Stage Modulation: A 
B0    CONSTANT UCBRF_11    \  USCI First Stage Modulation: B 
C0    CONSTANT UCBRF_12    \  USCI First Stage Modulation: C 
D0    CONSTANT UCBRF_13    \  USCI First Stage Modulation: D 
E0    CONSTANT UCBRF_14    \  USCI First Stage Modulation: E 
F0    CONSTANT UCBRF_15    \  USCI First Stage Modulation: F 

00    CONSTANT UCBRS_0     \  USCI Second Stage Modulation: 0 
02    CONSTANT UCBRS_1     \  USCI Second Stage Modulation: 1 
04    CONSTANT UCBRS_2     \  USCI Second Stage Modulation: 2 
06    CONSTANT UCBRS_3     \  USCI Second Stage Modulation: 3 
08    CONSTANT UCBRS_4     \  USCI Second Stage Modulation: 4 
0A    CONSTANT UCBRS_5     \  USCI Second Stage Modulation: 5 
0C    CONSTANT UCBRS_6     \  USCI Second Stage Modulation: 6 
0E    CONSTANT UCBRS_7     \  USCI Second Stage Modulation: 7 

80    CONSTANT UCLISTEN    \  USCI Listen mode 
40    CONSTANT UCFE        \  USCI Frame Error Flag 
20    CONSTANT UCOE        \  USCI Overrun Error Flag 
10    CONSTANT UCPE        \  USCI Parity Error Flag 
08    CONSTANT UCBRK       \  USCI Break received 
04    CONSTANT UCRXERR     \  USCI RX Error Flag 
02    CONSTANT UCADDR      \  USCI Address received Flag 
01    CONSTANT UCBUSY      \  USCI Busy Flag 
02    CONSTANT UCIDLE      \  USCI Idle line detected Flag 

\ CONSTANT res       80    \  reserved 
\ CONSTANT res       40    \  reserved 
\ CONSTANT res       20    \  reserved 
\ CONSTANT res       10    \  reserved 
08    CONSTANT UCNACKIE    \  NACK Condition interrupt enable 
04    CONSTANT UCSTPIE     \  STOP Condition interrupt enable 
02    CONSTANT UCSTTIE     \  START Condition interrupt enable 
01    CONSTANT UCALIE      \  Arbitration Lost interrupt enable 

40    CONSTANT UCSCLLOW    \  SCL low 
20    CONSTANT UCGC        \  General Call address received Flag 
10    CONSTANT UCBBUSY     \  Bus Busy Flag 
08    CONSTANT UCNACKIFG   \  NAK Condition interrupt Flag 
04    CONSTANT UCSTPIFG    \  STOP Condition interrupt Flag 
02    CONSTANT UCSTTIFG    \  START Condition interrupt Flag 
01    CONSTANT UCALIFG     \  Arbitration Lost interrupt Flag 

80    CONSTANT UCIRTXPL5   \  IRDA Transmit Pulse Length 5 
40    CONSTANT UCIRTXPL4   \  IRDA Transmit Pulse Length 4 
20    CONSTANT UCIRTXPL3   \  IRDA Transmit Pulse Length 3 
10    CONSTANT UCIRTXPL2   \  IRDA Transmit Pulse Length 2 
08    CONSTANT UCIRTXPL1   \  IRDA Transmit Pulse Length 1 
04    CONSTANT UCIRTXPL0   \  IRDA Transmit Pulse Length 0 
02    CONSTANT UCIRTXCLK   \  IRDA Transmit Pulse Clock Select 
01    CONSTANT UCIREN      \  IRDA Encoder/Decoder enable 

80    CONSTANT UCIRRXFL5   \  IRDA Receive Filter Length 5 
40    CONSTANT UCIRRXFL4   \  IRDA Receive Filter Length 4 
20    CONSTANT UCIRRXFL3   \  IRDA Receive Filter Length 3 
10    CONSTANT UCIRRXFL2   \  IRDA Receive Filter Length 2 
08    CONSTANT UCIRRXFL1   \  IRDA Receive Filter Length 1 
04    CONSTANT UCIRRXFL0   \  IRDA Receive Filter Length 0 
02    CONSTANT UCIRRXPL    \  IRDA Receive Input Polarity 
01    CONSTANT UCIRRXFE    \  IRDA Receive Filter enable 

\ CONSTANT res       80    \  reserved 
\ CONSTANT res       40    \  reserved 
20    CONSTANT UCDELIM1    \  Break Sync Delimiter 1 
10    CONSTANT UCDELIM0    \  Break Sync Delimiter 0 
08    CONSTANT UCSTOE      \  Sync-Field Timeout error 
04    CONSTANT UCBTOE      \  Break Timeout error 
\ CONSTANT res       02    \  reserved 
01    CONSTANT UCABDEN     \  Auto Baud Rate detect enable 

8000  CONSTANT UCGCEN      \  I2C General Call enable 
0200  CONSTANT UCOA9       \  I2C Own Address 9 
0100  CONSTANT UCOA8       \  I2C Own Address 8 
0080  CONSTANT UCOA7       \  I2C Own Address 7 
0040  CONSTANT UCOA6       \  I2C Own Address 6 
0020  CONSTANT UCOA5       \  I2C Own Address 5 
0010  CONSTANT UCOA4       \  I2C Own Address 4 
0008  CONSTANT UCOA3       \  I2C Own Address 3 
0004  CONSTANT UCOA2       \  I2C Own Address 2 
0002  CONSTANT UCOA1       \  I2C Own Address 1 
0001  CONSTANT UCOA0       \  I2C Own Address 0 

0200  CONSTANT UCSA9       \  I2C Slave Address 9 
0100  CONSTANT UCSA8       \  I2C Slave Address 8 
0080  CONSTANT UCSA7       \  I2C Slave Address 7 
0040  CONSTANT UCSA6       \  I2C Slave Address 6 
0020  CONSTANT UCSA5       \  I2C Slave Address 5 
0010  CONSTANT UCSA4       \  I2C Slave Address 4 
0008  CONSTANT UCSA3       \  I2C Slave Address 3 
0004  CONSTANT UCSA2       \  I2C Slave Address 2 
0002  CONSTANT UCSA1       \  I2C Slave Address 1 
0001  CONSTANT UCSA0       \  I2C Slave Address 0 

\ WATCHDOG TIMER

\ __MSP430_HAS_WDT_             CONSTANT \  Definition to show that Module is available 

0120  CONSTANT WDTCTL      \  Watchdog Timer Control 
\  The bit names have been prefixed with "WDT" 
0001 CONSTANT WDTIS0     
0002 CONSTANT WDTIS1     
0004 CONSTANT WDTSSEL    
0008 CONSTANT WDTCNTCL   
0010 CONSTANT WDTTMSEL   
0020 CONSTANT WDTNMI     
0040 CONSTANT WDTNMIES   
0080 CONSTANT WDTHOLD    

5A00 CONSTANT WDTPW      

\  WDT-interval times [1ms] coded with Bits 0-2 
\  WDT is clocked by fSMCLK (assumed 1MHz) 
WDTPW WDTTMSEL + WDTCNTCL                         + CONSTANT WDT_MDLY_32          \  32ms interval (default) 
WDTPW WDTTMSEL + WDTCNTCL + WDTIS0                  + CONSTANT WDT_MDLY_8 \  8ms     " 
WDTPW WDTTMSEL + WDTCNTCL + WDTIS1                  + CONSTANT WDT_MDLY_0_5         \  0.5ms   " 
WDTPW WDTTMSEL + WDTCNTCL + WDTIS1 + WDTIS0           + CONSTANT WDT_MDLY_0_064       \  0.064ms " 
\  WDT is clocked by fACLK (assumed 32KHz) 
WDTPW WDTTMSEL + WDTCNTCL + WDTSSEL                 + CONSTANT WDT_ADLY_1000        \  1000ms  " 
WDTPW WDTTMSEL + WDTCNTCL + WDTSSEL + WDTIS0          + CONSTANT WDT_ADLY_250         \  250ms   " 
WDTPW WDTTMSEL + WDTCNTCL + WDTSSEL + WDTIS1          + CONSTANT WDT_ADLY_16          \  16ms    " 
WDTPW WDTTMSEL + WDTCNTCL + WDTSSEL + WDTIS1 + WDTIS0   + CONSTANT WDT_ADLY_1_9         \  1.9ms   " 
\  Watchdog mode -> reset after expired time 
\  WDT is clocked by fSMCLK (assumed 1MHz) 
WDTPW WDTCNTCL                                  + CONSTANT WDT_MRST_32          \  32ms interval (default) 
WDTPW WDTCNTCL + WDTIS0                           + CONSTANT WDT_MRST_8 \  8ms     " 
WDTPW WDTCNTCL + WDTIS1                           + CONSTANT WDT_MRST_0_5         \  0.5ms   " 
WDTPW WDTCNTCL + WDTIS1 + WDTIS0                    + CONSTANT WDT_MRST_0_064       \  0.064ms " 
\  WDT is clocked by fACLK (assumed 32KHz) 
WDTPW WDTCNTCL + WDTSSEL                          + CONSTANT WDT_ARST_1000        \  1000ms  " 
WDTPW WDTCNTCL + WDTSSEL + WDTIS0                   + CONSTANT WDT_ARST_250         \  250ms   " 
WDTPW WDTCNTCL + WDTSSEL + WDTIS1                   + CONSTANT WDT_ARST_16          \  16ms    " 
WDTPW WDTCNTCL + WDTSSEL + WDTIS1 + WDTIS0            + CONSTANT WDT_ARST_1_9         \  1.9ms   " 

\  INTERRUPT CONTROL 
\  These two bits are defined in the Special Function Registers 
\  CONSTANT WDTIE                01 
\  CONSTANT WDTIFG               01 

\ Calibration Data in Info Mem


\ #ifndef __DisableCalData

10F8  CONSTANT CALDCO_16MHZ            \  DCOCTL  Calibration Data for 16MHz 
10F9  CONSTANT CALBC1_16MHZ            \  BCSCTL1 Calibration Data for 16MHz 
10FA  CONSTANT CALDCO_12MHZ            \  DCOCTL  Calibration Data for 12MHz 
10FB  CONSTANT CALBC1_12MHZ            \  BCSCTL1 Calibration Data for 12MHz 
10FC  CONSTANT CALDCO_8MHZ   \  DCOCTL  Calibration Data for 8MHz 
10FD  CONSTANT CALBC1_8MHZ   \  BCSCTL1 Calibration Data for 8MHz 
10FE  CONSTANT CALDCO_1MHZ   \  DCOCTL  Calibration Data for 1MHz 
10FF  CONSTANT CALBC1_1MHZ   \  BCSCTL1 Calibration Data for 1MHz 

\ #endif \  \ #ifndef __DisableCalData 

\ Interrupt Vectors (offset from  FFE0)


2 2  * CONSTANT PORT1_VECTOR         \   FFE4 Port 1 
3 2  * CONSTANT PORT2_VECTOR         \   FFE6 Port 2 
5 2  * CONSTANT ADC10_VECTOR         \   FFEA ADC10 
6 2  * CONSTANT USCIAB0TX_VECTOR     \   FFEC USCI A0/B0 Transmit 
7 2  * CONSTANT USCIAB0RX_VECTOR     \   FFEE USCI A0/B0 Receive 
8 2  * CONSTANT TIMER0_A1_VECTOR     \   FFF0 Timer0A CC1, TA0 
9 2  * CONSTANT TIMER0_A0_VECTOR     \   FFF2 Timer0_A CC0 
10 2 * CONSTANT WDT_VECTOR \   FFF4 Watchdog Timer 
11 2 * CONSTANT COMPARATORA_VECTOR   \   FFF6 Comparator A 
12 2 * CONSTANT TIMER1_A1_VECTOR     \   FFF8 Timer1_A CC1-4, TA1 
13 2 * CONSTANT TIMER1_A0_VECTOR     \   FFFA Timer1_A CC0 
14 2 * CONSTANT NMI_VECTOR \   FFFC Non-maskable 
15 2 * CONSTANT RESET_VECTOR         \   FFFE Reset [Highest Priority] 

\ End of Modules

Forth Definitions

